@@ -1,7 +1,7 @@
-import json
-import csv
 import os
 import sys
+import csv
+import json
 from mnrva.utils import console
 
 
@@ -26,14 +26,6 @@ class FileSystem(object):
 			console.error('-- Error -- Read file csv')
 			return None
 
-	def getSchema(self, filename):
-		fileSchema = self.base_url + 'schemas/' + filename + '.sql'
-		if os.path.exists(fileSchema):
-			return fileSchema
-		else:
-			console.error('-- Error -- Schema Not found')
-			return None
-
 	def makeDir(self, directory):
 		path_dir = self.base_url + directory
 		if not os.path.exists(path_dir):
