@@ -1,14 +1,25 @@
 import json
 import re
 import multiprocessing
+import datetime
 
 
-def use(package, lib=''):
-	if lib == '':
-		lib = package.title()
-	package = __import__('mnrva.' + package, fromlist=lib)
-	method = getattr(package, lib)
-	return method
+def jsonDate(o):
+	if isinstance(o, datetime.datetime):
+		return o.__str__()
+
+
+def dateGMT(date_c, gmt):
+	date_tmp = datetime.datetime.strptime(date_c, '%Y-%m-%dT%H:%M:%S%z') + datetime.timedelta(hours=gmt)
+	return date_tmp.strftime('%Y-%m-%dT%H:%M:%S%z')
+
+
+def getInt(num):
+	try:
+		return int(num)
+	except:
+		return 0
+
 
 def removeEmoji(text):
 	try:
@@ -18,6 +29,7 @@ def removeEmoji(text):
 
 	return emojis.sub(u'', text)
 
+
 def runWorkers(workers, method):
 	processes = [multiprocessing.Process(target=method, args=(w,)) for w in workers]
 	[process.start() for process in processes]
